# ἐντελέχεια 【en.te.lé.kʰeː.a】

[![home-img]][home-url]
[![course-img]][course-url]
[![lecture-img]][lecture-url]
[![research-img]][research-url]
[![linkedin-img]][linkedin-url]

[home-img]: https://img.shields.io/badge/home-entelecheia.me-blue
[home-url]: https://entelecheia.me
[course-img]: https://img.shields.io/badge/course-entelecheia.ai-blue
[course-url]: https://course.entelecheia.ai
[lecture-img]: https://img.shields.io/badge/lecture-entelecheia.ai-blue
[lecture-url]: https://lecture.entelecheia.ai
[research-img]: https://img.shields.io/badge/research-entelecheia.ai-blue
[research-url]: https://research.entelecheia.ai
[linkedin-img]: https://img.shields.io/badge/LinkedIn-blue?logo=linkedin
[linkedin-url]: https://www.linkedin.com/in/entelecheia/

Coined by Aristotle from ἐντελής (entelḗs, “complete, full, accomplished”) + ἔχειν (ékhein, “have, hold”).

[![Top Langs](https://github-readme-stats.vercel.app/api/top-langs/?username=entelecheia&layout=compact&size_weight=0.1&count_weight=0.9&langs_count=10&theme=transparent&card_width=400&hide_border=true)](https://entelecheia.me/repositories/) [![GitHub Streak](https://streak-stats.demolab.com?user=entelecheia&theme=transparent&hide_border=true&card_width=400)](https://entelecheia.me/repositories/)

[![entelecheia's wakatime stats](https://github-readme-stats.vercel.app/api/wakatime?username=entelecheia&layout=compact&theme=transparent&hide_border=true&hide=other,browsing,shell,writing,reviewing,searching,researching,github,ai,text)](https://wakatime.com/@entelecheia)
